@@ -77,13 +77,14 @@ int parseParenthesizedListHelper( const QByteArray & data, T& result, int start
   int sublistbegin = start;
   bool insideQuote = false;
   for ( int i = begin + 1; i < data.length(); ++i ) {
-    if ( data[i] == '(' && !insideQuote ) {
+    const char currentChar = data[i];
+    if ( currentChar == '(' && !insideQuote ) {
       ++count;
       if ( count == 1 )
         sublistbegin = i;
       continue;
     }
-    if ( data[i] == ')' && !insideQuote ) {
+    if ( currentChar == ')' && !insideQuote ) {
       if ( count <= 0 )
         return i + 1;
       if ( count == 1 )
@@ -91,7 +92,7 @@ int parseParenthesizedListHelper( const QByteArray & data, T& result, int start
       --count;
       continue;
     }
-    if ( data[i] == ' ' || data[i] == '\n' || data[i] == '\r' )
+    if ( currentChar == ' ' || currentChar == '\n' || currentChar == '\r' )
        continue;
     if ( count == 0 ) {
       QByteArray ba;
@@ -99,9 +100,9 @@ int parseParenthesizedListHelper( const QByteArray & data, T& result, int start
       i = consumed - 1; // compensate for the for loop increment
       result.append( ba );
     } else if ( count > 0 ) {
-      if ( data[i] == '"' ) {
+      if ( currentChar == '"' ) {
         insideQuote = !insideQuote;
-      } else if ( data[i] == '\\' && insideQuote ) {
+      } else if ( currentChar == '\\' && insideQuote ) {
         ++i;
         continue;
       }
@@ -200,12 +201,13 @@ int ImapParser::parseQuotedString( const QByteArray & data, QByteArray &result,
   else {
     bool reachedInputEnd = true;
     for ( int i = begin; i < data.length(); ++i ) {
-      if ( data[i] == ' ' || data[i] == '(' || data[i] == ')' || data[i] == '\n' || data[i] == '\r' ) {
+      const char ch = data.at( i );
+      if ( ch == ' ' || ch == '(' || ch == ')' || ch == '\n' || ch == '\r' ) {
         end = i;
         reachedInputEnd = false;
         break;
       }
-      if (data[i] == '\\') 
+      if ( ch == '\\' )
         foundSlash = true;
     }
     if ( reachedInputEnd )
@@ -242,19 +244,20 @@ int ImapParser::parenthesesBalance( const QByteArray & data, int start )
   int count = 0;
   bool insideQuote = false;
   for ( int i = start; i < data.length(); ++i ) {
-    if ( data[i] == '"' ) {
+    const char ch = data[i];
+    if ( ch == '"' ) {
       insideQuote = !insideQuote;
       continue;
     }
-    if ( data[i] == '\\' && insideQuote ) {
+    if ( ch == '\\' && insideQuote ) {
       ++i;
       continue;
     }
-    if ( data[i] == '(' && !insideQuote ) {
+    if ( ch == '(' && !insideQuote ) {
       ++count;
       continue;
     }
-    if ( data[i] == ')' && !insideQuote ) {
+    if ( ch == ')' && !insideQuote ) {
       --count;
       continue;
     }
@@ -264,14 +267,28 @@ int ImapParser::parenthesesBalance( const QByteArray & data, int start )
 
 QByteArray ImapParser::join(const QList< QByteArray > & list, const QByteArray & separator)
 {
+  // shortcuts for the easy cases
   if ( list.isEmpty() )
     return QByteArray();
+  if ( list.size() == 1 )
+    return list.first();
 
-  QByteArray result = list.first();
-  QList<QByteArray>::ConstIterator it = list.constBegin();
+  // avoid expensive realloc's by determining the size beforehand
+  QList<QByteArray>::const_iterator it = list.constBegin();
+  const QList<QByteArray>::const_iterator endIt = list.constEnd();
+  int resultSize = (list.size() - 1) * separator.size();
+  for ( ; it != endIt; ++it )
+    resultSize += (*it).size();
+
+  QByteArray result;
+  result.reserve( resultSize );
+  it = list.constBegin();
+  result += (*it);
   ++it;
-  for ( ; it != list.constEnd(); ++it )
-    result += separator + (*it);
+  for ( ; it != endIt; ++it ) {
+    result += separator;
+    result += (*it);
+  }
 
   return result;
 }
@@ -310,24 +327,43 @@ int ImapParser::parseNumber(const QByteArray & data, qint64 & result, bool * ok,
 
 QByteArray ImapParser::quote(const QByteArray & data)
 {
-  QByteArray result( "\"" );
-  result.reserve( data.length() + 2 );
-  for ( int i = 0; i < data.length(); ++i ) {
-    const char ch = data.at( i );
-    if ( ch == '\n' ) {
-      result += "\\n";
-      continue;
-    }
+  if ( data.isEmpty() )
+    return QByteArray( "\"\"" );
 
-    if ( ch == '\r' ) {
-      result += "\\r";
-      continue;
-    }
- 
-    if ( ch == '"' || ch == '\\' )
-      result += '\\';
-    result += ch;
+  const int inputLength = data.length();
+  int stuffToQuote = 0;
+  for ( int i = 0; i < inputLength; ++i ) {
+    const char ch = data.at( i );
+    if ( ch == '"' || ch == '\\' || ch == '\n' || ch == '\r' )
+      ++stuffToQuote;
   }
+
+  QByteArray result;
+  result.reserve( inputLength + stuffToQuote + 2 );
+  result += '"';
+
+  // shortcut for the case that we don't need to quote anything at all
+  if ( stuffToQuote == 0 ) {
+    result += data;
+  } else {
+    for ( int i = 0; i < inputLength; ++i ) {
+      const char ch = data.at( i );
+      if ( ch == '\n' ) {
+        result += "\\n";
+        continue;
+      }
+
+      if ( ch == '\r' ) {
+        result += "\\r";
+        continue;
+      }
+
+      if ( ch == '"' || ch == '\\' )
+        result += '\\';
+      result += ch;
+    }
+  }
+
   result += '"';
   return result;
 }
