@@ -51,7 +51,11 @@ class AKONADIPROTOCOLINTERNALS_EXPORT NotificationMessage
       Add,
       Modify,
       Move,
-      Remove
+      Remove,
+      Link,
+      Unlink,
+      Subscribe,
+      Unsubscribe
     };
 
     NotificationMessage();
