@@ -41,7 +41,7 @@ namespace Akonadi {
  * for .desktop files in the agent directory) and the available configured
  * instances.
  */
-class AgentManager : public QObject
+class AgentManager : public QObject, protected QDBusContext
 {
   Q_OBJECT
   Q_CLASSINFO( "D-Bus Interface", "org.freedesktop.Akonadi.AgentManager" )
@@ -305,6 +305,7 @@ class AgentManager : public QObject
     void updatePluginInfos();
     void serviceOwnerChanged( const QString&, const QString&, const QString& );
     void agentExeChanged( const QString &fileName );
+    void serverFailure();
 
   private:
     /**
@@ -324,12 +325,12 @@ class AgentManager : public QObject
     void save();
 
     /**
-     * Reads the plugin infos from directory.
+     * Reads the plugin information from directory.
      */
     void readPluginInfos();
 
     /**
-     * Reads the plugin infos from directory.
+     * Reads the plugin information from directory.
      *
      * @param directory the directory to get plugin information from
      */
