@@ -31,7 +31,6 @@ namespace Akonadi {
     class Handler;
     class Response;
     class DataStore;
-    class ImapParser;
     class Collection;
     class ImapStreamParser;
 
@@ -56,6 +55,7 @@ public:
       Returns @c true if this connection belongs to the owning resource of @p item.
     */
     bool isOwnerResource( const PimItem &item ) const;
+    bool isOwnerResource( const Collection &collection ) const;
 
     const Collection selectedCollection();
 
@@ -90,7 +90,6 @@ private:
     QList<QByteArray> m_statusMessageQueue;
     QString m_identifier;
     QByteArray m_sessionId;
-    ImapParser *m_parser;
     ImapStreamParser *m_streamParser;
     Resource m_resourceContext;
 };
