@@ -48,8 +48,8 @@ bool Status::parseStream()
 
     // Syntax:
     // status     = "STATUS" SP mailbox SP "(" status-att *(SP status-att) ")"
-    // status-att = "MESSAGES" / "RECENT" / "UIDNEXT" / "UIDVALIDITY" / "UNSEEN"
-  
+    // status-att = "MESSAGES" / "RECENT" / "UIDNEXT" / "UIDVALIDITY" / "UNSEEN" / "SIZE"
+
   QByteArray mailbox = m_streamParser->readString();
   QList<QByteArray> attributeList = m_streamParser->readParenthesizedList();
 
@@ -106,11 +106,22 @@ bool Status::parseStream()
     else
       statusResponse += "UNSEEN ";
 
-    const int count = HandlerHelper::itemWithoutFlagCount( col, QLatin1String( "\\Seen" ) );
+    const int count = HandlerHelper::itemWithoutFlagCount( col, QLatin1String( "\\SEEN" ) );
     if ( count < 0 )
       return failureResponse( "Unable to retrieve unread count" );
     statusResponse += QByteArray::number( count );
   }
+  if ( attributeList.contains( "SIZE" ) ) {
+    if ( !statusResponse.isEmpty() )
+      statusResponse += " SIZE ";
+    else
+      statusResponse += "SIZE ";
+
+    const qint64 size = HandlerHelper::itemsTotalSize( col );
+    if ( size < 0 )
+      return failureResponse( "Unable to retrieve collection total size" );
+    statusResponse += QByteArray::number( size );
+  }
 
   response.setUntagged();
   response.setString( "STATUS \"" + HandlerHelper::pathForCollection( col ).toUtf8() + "\" (" + statusResponse + ')' );
@@ -120,10 +131,7 @@ bool Status::parseStream()
   response.setTag( tag() );
   response.setString( "STATUS completed" );
   emit responseAvailable( response );
-
-  deleteLater();
   return true;
-
 }
 
 #include "status.moc"
