@@ -37,6 +37,8 @@ AKONADI_EXCEPTION_MAKE_INSTANCE( ImapParserException );
 
 class QIODevice;
 
+class ImapStreamParserTest;
+
 namespace Akonadi {
 
 /**
@@ -44,6 +46,8 @@ namespace Akonadi {
 */
 class AKONADIPRIVATE_EXPORT ImapStreamParser
 {
+  friend class ::ImapStreamParserTest;
+
   public:
     /**
      * Construct the parser.
@@ -69,6 +73,12 @@ class AKONADIPRIVATE_EXPORT ImapStreamParser
      */
     QByteArray readString();
 
+    /**
+     * Same as above, but without actually moving the stream position forward.
+     * @return the next string from the stream, without modifying the stream.
+     */
+    QByteArray peekString();
+
     /**
      * Get he next IMAP sequence set. If the upcoming data is not an IMAP sequence set,
      * the behavior is undefined. Use @ref hasSequenceSet to be sure a sequence set comes. This call might block.
@@ -192,11 +202,20 @@ class AKONADIPRIVATE_EXPORT ImapStreamParser
     bool atCommandEnd();
 
     /**
-     * Return everything that remained from the command.
+     * Return everything that remained from the command, <em>including not yet
+     * requested</em> literal parts.
      * @return the remaining command data
+     * @see skipCurrentCommand
      */
     QByteArray readUntilCommandEnd();
 
+    /**
+     * This reads until the end of the <em>already sent</em> command and does not
+     * request not yet sent literal parts.
+     * @see readUntilCommandEnd
+     */
+    void skipCurrentCommand();
+
     /**
      * Return all the data that was read from the socket, but not processed yet.
      * @return the remaining unprocessed data
@@ -222,6 +241,11 @@ class AKONADIPRIVATE_EXPORT ImapStreamParser
      */
     void stripLeadingSpaces();
 
+    /**
+     * Set the identification used for Tracer calls.
+     */
+    void setTracerIdentifier( const QString& id );
+
   private:
     QByteArray parseQuotedString();
 
@@ -235,15 +259,17 @@ class AKONADIPRIVATE_EXPORT ImapStreamParser
 
     /**
      * Inform the client to send more literal data.
+     * @param size size of the requested literal in bytes
      */
-    void sendContinuationResponse();
+    void sendContinuationResponse( qint64 size );
 
     QIODevice *m_socket;
     QByteArray m_data;
     QByteArray m_tag;
+    QString m_tracerId;
     int m_position;
     qint64 m_literalSize;
-    qint64 m_continuationSize;
+    bool m_peeking;
 };
 
 }
