@@ -24,7 +24,7 @@
 #include <QtCore/QSet>
 #include <QtCore/QString>
 
-#include "search/queryserviceclient.h"
+#include "nepomuk/queryserviceclient.h"
 
 namespace Akonadi {
 
