@@ -25,7 +25,6 @@
 #include <QThread>
 
 namespace Akonadi {
-namespace Server {
 
 /** Container thread for the item retrieval manager. */
 class ItemRetrievalThread : public QThread
@@ -38,7 +37,6 @@ class ItemRetrievalThread : public QThread
     /* reimpl */ void run();
 };
 
-} // namespace Server
-} // namespace Akonadi
+}
 
 #endif
