@@ -24,6 +24,7 @@
 #endif
 
 #include <QSqlRecord>
+#include <QSqlError>
 
 using namespace Akonadi;
 
@@ -88,6 +89,7 @@ QueryBuilder::QueryBuilder( const QString& table, QueryBuilder::QueryType type )
     mDatabaseType( Unknown ),
 #endif
     mType( type ),
+    mLimit( -1 ),
     mDistinct( false )
 {
 }
@@ -264,6 +266,10 @@ bool QueryBuilder::exec()
     statement += orderStmts.join( QLatin1String( ", " ) );
   }
 
+  if ( mLimit > 0 ) {
+    statement += QString::fromLatin1( " LIMIT %1" ).arg( mLimit );
+  }
+
 #ifndef QUERYBUILDER_UNITTEST
   mQuery.prepare( statement );
   //too heavy debug info but worths to have from time to time
@@ -374,6 +380,11 @@ void QueryBuilder::setDistinct(bool distinct)
   mDistinct = distinct;
 }
 
+void QueryBuilder::setLimit(int limit)
+{
+  mLimit = limit;
+}
+
 qint64 QueryBuilder::insertId()
 {
   if ( mDatabaseType == PostgreSQL ) {
@@ -396,7 +407,7 @@ QueryBuilder::DatabaseType QueryBuilder::qsqlDriverNameToDatabaseType (const QSt
     return MySQL;
   if ( driverName == QLatin1String( "QPSQL" ) )
     return PostgreSQL;
-  if ( driverName.startsWith( QLatin1String( "SQLITE" ) ) )
+  if ( driverName.startsWith( QLatin1String( "QSQLITE" ) ) )
     return Sqlite;
   return Unknown;
 }
