@@ -28,13 +28,12 @@ class DbInitializerTest : public QObject
   Q_OBJECT
 
   private Q_SLOTS:
-    void initTestCase();
-
-    void testRun_data();
-    void testRun();
+    void testMysqlCreateTableStatement();
+    void testPsqlCreateTableStatement();
+    void testSqliteCreateTableStatement();
 
   private:
-    static QString readNextStatement( QIODevice *io );
+    void runCreateTableStatementTest( const QString&, const QString& );
 };
 
 #endif
